class StepsController < ApplicationController
  before_filter :find_use_case

  # GET /steps
  # GET /steps.xml
  def index
    @steps = Step.find(:all)

    respond_to do |format|
      format.html { redirect_to :controller => "use_cases", :action => "show",
        :id => @use_case }
      format.xml { render :xml => @steps.to_xml }
    end
  end

  # GET /step/1
  # GET /step/1.xml
  def show
    respond_to do |format|
      format.html { redirect_to :controller => "use_cases", :action => "show",
        :id => @use_case }
      format.xml do
        @step = Step.find(params[:id])
        render :xml => @step.to_xml
      end
    end
  end

  # GET /step/new
  def new
    @step = @use_case.steps.build
  end

  # GET /step/1;edit
  def edit
    @step = Step.find(params[:id])
  end

  # POST /steps
  # POST /steps.xml
  def create
    @step = @use_case.steps.build(params[:step])

    respond_to do |format|
      if @step.save
        flash[:notice] = "Step was successfully added."
        format.html { redirect_to use_case_url(@use_case) }
        format.xml  { head :created, :location => step_url(@step) }
      else
        format.html { render :action => "new" }
        format.xml  { render :xml => @step.errors.to_xml }
      end
    end
  end

  # PUT /step/1
  # PUT /step/1.xml
  def update
    @step = Step.find(params[:id])

    respond_to do |format|
      if @step.update_attributes(params[:step])
        flash[:notice] = "Step was successfully updated."
        format.html { redirect_to use_case_url(@use_case) }
        format.xml  { head :ok }
      else
        format.html { render :action => "edit" }
        format.xml  { render :xml => @step.errors.to_xml }
      end
    end
  end

  # DELETE /step/1
  # DELETE /step/1.xml
  def destroy
    @step = Step.find(params[:id])
    @step.destroy

    respond_to do |format|
      format.html { redirect_to use_case_url(@use_case) }
      format.xml  { head :ok }
    end
  end

  # PUT /step/1;up
  def up
    @step = Step.find(params[:id])
    @step.move_higher

    respond_to do |format|
      format.html { redirect_to use_case_url(@use_case) }
      format.xml  { head :ok }
    end
  end

  # PUT /step/1;down
  def down
    @step = Step.find(params[:id])
    @step.move_lower

    respond_to do |format|
      format.html { redirect_to use_case_url(@use_case) }
      format.xml  { head :ok }
    end
  end

  private

  def find_use_case
    @use_case_id = params[:use_case_id]
    redirect_to use_cases_url unless @use_case_id
    @use_case  = UseCase.find(@use_case_id)
  end
end
