require File.dirname(__FILE__) + '/../test_helper'
require 'actors_controller'

# Re-raise errors caught by the controller.
class ActorsController; def rescue_action(e) raise e end; end

class ActorsControllerTest < Test::Unit::TestCase
  fixtures :actors

  def setup
    @controller = ActorsController.new
    @request    = ActionController::TestRequest.new
    @response   = ActionController::TestResponse.new
  end

  def test_index
    get :index
    assert_template "index"
    assert_response :success
  end

  def test_new
    get :new
    assert_template "new"
  end

  def test_create
    count_before = Actor.count
    post :create, :actor => { :name => "Designer", :description => "A designer"}
    assert_redirected_to :action => "index"
    assert_equal "Actor was successfully created.", flash[:notice]
    assert_equal Actor.count - 1, count_before
  end

  def test_create_invalid_actor
    count_before = Actor.count
    post :create, :actor => { :name => "", :description => "A designer" }
    assert_template "new"
    assert_equal Actor.count, count_before
  end

  def test_show
    get :show, :id => 1
    assert_template "show"
    assert_not_nil assigns["actor"]
  end

  def test_edit
    get :edit, :id => 1
    assert_template "edit"
    assert_not_nil assigns["actor"]
  end

  def test_update
    put :update, :id => 1, :actor => {
      :name => "Analyst", :description => "A system analyst" }
    assert_redirected_to :action => "index"
    assert_equal "Actor was successfully updated.", flash[:notice]
  end

  def test_update_with_invalid_data
    post :update, :id => 1, :actor => {
      :name => "", :description => "A system analyst" }
    assert_template "edit"
  end

  def test_destroy
    count_before = Actor.count
    delete :destroy, :id => 1
    assert_redirected_to :action => "index"
    assert_equal Actor.count + 1, count_before
  end

end
