require File.dirname(__FILE__) + '/../test_helper'
require 'steps_controller'

# Re-raise errors caught by the controller.
class StepsController; def rescue_action(e) raise e end; end

class StepsControllerTest < Test::Unit::TestCase
  fixtures :use_cases, :steps

  def setup
    @controller = StepsController.new
    @request    = ActionController::TestRequest.new
    @response   = ActionController::TestResponse.new
  end

  def test_index
    get :index, :use_case_id => 1, :id => 1
    assert_redirected_to :controller => "use_cases", :action => "show",
      :id => 1
  end

  def test_new
    get :new, :use_case_id => 1
    assert_template "new"
  end

  def test_create
    count_before = use_cases(:full).steps.count
    post :create, :use_case_id => 1,
      :step => { :description => "Just do something..."}
    assert_redirected_to :action => "show"
    assert_equal "Step was successfully added.", flash[:notice]
    assert_equal use_cases(:full).steps.count - 1, count_before
  end

  def test_create_invalid_step
    count_before = use_cases(:full).steps.count
    post :create, :use_case_id => 1, :step => { :use_case_id => 1,
      :description => ""}
    assert_template "new"
    assert_equal use_cases(:full).steps.count, count_before
  end

  def test_show
    get :show, :use_case_id => 1, :id => 1
    assert_redirected_to :controller => "use_cases", :action => "show", :id => 1
  end

  def test_edit
    get :edit, :use_case_id => 1, :id => 1
    assert_template "edit"
    assert_not_nil assigns["step"]
  end

  def test_update
    put :update, :use_case_id => 1, :id => 1, :step => {
      :description => "Just the first step" }
    assert_redirected_to :controller => "use_cases", :action => "show", :id => 1
    assert_equal "Step was successfully updated.", flash[:notice]
  end

  def test_update_with_invalid_data
    post :update, :use_case_id => 1, :id => 1, :step => { :description => "" }
    assert_template "edit"
  end

  def test_destroy
    count_before = use_cases(:full).steps.count
    delete :destroy, :use_case_id => 1, :id => 1
    assert_redirected_to :controller => "use_cases", :action => "show", :id => 1
    assert_equal use_cases(:full).steps.count + 1, count_before
  end

  def test_move_up
    step = steps(:last)
    pos_before = step.position
    put :up, :use_case_id => 1, :id => step
    step.reload
    assert_equal pos_before - 1, step.position
  end

  def test_move_down
    step = steps(:first)
    pos_before = step.position
    put :down, :use_case_id => 1, :id => step
    step.reload
    assert_equal pos_before + 1, step.position
  end
end
