require File.dirname(__FILE__) + '/../test_helper'
require 'use_cases_controller'

# Re-raise errors caught by the controller.
class UseCasesController; def rescue_action(e) raise e end; end

class UseCasesControllerTest < Test::Unit::TestCase
  fixtures :actors, :use_cases

  def setup
    @controller = UseCasesController.new
    @request    = ActionController::TestRequest.new
    @response   = ActionController::TestResponse.new
  end

  def test_index
    get :index
    assert_template "index"
    assert_response :success
  end

  def test_new
    get :new
    assert_template "new"
  end

  def test_create
    count_before = UseCase.count
    post :create, :use_case => { :name => "Designer",
      :description => "Add a use case to use cases' model",
      :actor_id => 1 }
    assert_redirected_to :action => "show"
    assert_equal "Use case was successfully created.", flash[:notice]
    assert_equal UseCase.count - 1, count_before
  end

  def test_create_invalid_use_case
    count_before = UseCase.count
    post :create, :actor => { :name => "", :description => "A dummy use case" }
    assert_template "new"
    assert_equal UseCase.count, count_before
  end

  def test_show
    get :show, :id => 1
    assert_template "show"
    assert_not_nil assigns["use_case"]
  end

  def test_edit
    get :edit, :id => 1
    assert_template "edit"
    assert_not_nil assigns["use_case"]
  end

  def test_update
    put :update, :id => 1, :use_case => {
      :name => "Analyst", :description => "A system analyst" }
    assert_redirected_to :action => "show"
    assert_equal "Use case was successfully updated.", flash[:notice]
  end

  def test_update_with_invalid_data
    post :update, :id => 1, :use_case => {
      :name => "", :description => "A system analyst" }
    assert_template "edit"
  end

  def test_destroy
    count_before = UseCase.count
    delete :destroy, :id => 1
    assert_redirected_to :action => "index"
    assert_equal UseCase.count + 1, count_before
  end

end
